@@ -1,9 +1,6 @@
 # -*- coding: utf8 -*-
-from attest import AssertImportHook, Tests
-AssertImportHook.enable()
-
+from .environment import testing_environment  # enables assert import hook
 from .assertion import Assert
-from .environment import testing_environment
 from .reporters import (AbstractReporter, PlainReporter, FancyReporter,
                         auto_reporter, XmlReporter, QuickFixReporter)
 from django.test import TestCase, TransactionTestCase
